*/ Script Autor: Fbio Marques Simoes de Souza,
Psychobiology Sector, FFCLRP, University of Sao Paulo at Ribeirao Preto, 
Ribeiro Preto/SP, Brazil.
Adviser: Antonio Carlos Roque 
Physics and Mathematics Sector, FFCLRP, University of Sao Paulo at Ribeirao Preto, Ribeiro Preto/SP, Brazil.

/*
// Clchan.g - script that makes the Calcium-dependent chloride channel

float Ecl=0.006    // volts       
float dgclmax=56   // Siemens/m^2 (specific conductance)
float Knob_A=28*10e-12    //Dendritic Knob Area (meters^2)
float gclmax=Knob_A*dgclmax // 1,568pS

//========================================================================
//             Tabulated Ca-dependent Chloride Channel
//========================================================================

/* This is a tabchannel which gets the calcium concentration from Ca_conc
   in order to calculate the activation of its Z gate.  It is set up much
   like the Ca channel, except that the A and B tables have values which are
   functions of concentration, instead of voltage.
*/

function makeclchannel
        create  tabchannel      clchannel
                setfield        ^       \
                Ek              {Ecl}   \                   //      V
                Gbar            {gclmax}    \     //      S
                Ik              0       \                   //      A
                Gk              0                 \         //      S
                Xpower  0       \
                Ypower  0       \
                Zpower  1       \
                Z               0

// Allocate space in the Z gate A and B tables, covering a concentration
// range from xmin = 0 to xmax = 1000, with 50 divisions
        float   xmin = 0.0
        float   xmax = 1000.0
        int     xdivs = 50

        call clchannel TABCREATE Z {xdivs} {xmin} {xmax}
        int i
        float x,dx,y,z
        dx = (xmax - xmin)/xdivs
        x = xmin
        for (i = 0 ; i <= {xdivs} ; i = i + 1)
            y = x/(x+26)  //Hill equation to m_inf with Hill coefficient 1 
            z = 0//delay 0
            setfield clchannel Z_A->table[{i}] {z}
            setfield clchannel Z_B->table[{i}] {y}
            x = x + dx
        end
// For speed during execution, set the calculation mode to "no interpolation"
// and use TABFILL to expand the table to 3000 entries.
        setfield clchannel Z_A->calc_mode 0   Z_B->calc_mode 0
        call clchannel TABFILL Z  3000 0
        tweaktau clchannel Z
end
